Bug005: push fix to remotesw to add remote port.
Decrease lldp timers
diff --git a/src/main/java/net/floodlightcontroller/linkdiscovery/internal/LinkDiscoveryManager.java b/src/main/java/net/floodlightcontroller/linkdiscovery/internal/LinkDiscoveryManager.java
index 3df8bb8..78fe407 100644
--- a/src/main/java/net/floodlightcontroller/linkdiscovery/internal/LinkDiscoveryManager.java
+++ b/src/main/java/net/floodlightcontroller/linkdiscovery/internal/LinkDiscoveryManager.java
@@ -180,13 +180,13 @@
     // Link discovery task details.
     protected SingletonTask discoveryTask;
     protected final int DISCOVERY_TASK_INTERVAL = 1; 
-    protected final int LINK_TIMEOUT = 35; // timeout as part of LLDP process.
-    protected final int LLDP_TO_ALL_INTERVAL = 15 ; //15 seconds.
+    protected final int LINK_TIMEOUT = 5; // decreased timeout as part of LLDP process from 35 secs
+    protected final int LLDP_TO_ALL_INTERVAL = 2 ; //decreased from 15 seconds.
     protected long lldpClock = 0;
     // This value is intentionally kept higher than LLDP_TO_ALL_INTERVAL.
     // If we want to identify link failures faster, we could decrease this
     // value to a small number, say 1 or 2 sec.
-    protected final int LLDP_TO_KNOWN_INTERVAL= 20; // LLDP frequency for known links
+    protected final int LLDP_TO_KNOWN_INTERVAL= 2; // LLDP frequency for known links from 20 secs
 
     protected LLDPTLV controllerTLV;
     protected ReentrantReadWriteLock lock;
@@ -533,7 +533,7 @@
         }
         
         // add the port if we have not seen it before
-        if (remotesw.getPort(port) != null) {
+        if (remotesw.getPort(port) == null) {
         	OFPhysicalPort remoteport = new OFPhysicalPort();
         	remoteport.setPortNumber(port);
         	remoteport.setName("fake_" + port);